==> ugene_34.0+dfsg.orig.tar.xz: ugene-34.0/src/plugins/enzymes/src/CreateFragmentDialog.h <==
/**
 * UGENE - Integrated Bioinformatics Tools.
 * Copyright (C) 2008-2020 UniPro <ugene@unipro.ru>
 * http://ugene.net
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA 02110-1301, USA.
 */

#ifndef _U2_CREATE_FRAGMENT_DIALOG_H_
#define _U2_CREATE_FRAGMENT_DIALOG_H_

#include <QSet>
#include "DNAFragment.h"
#include <U2Gui/RegionSelector.h>
#include <ui_CreateFragmentDialog.h>

namespace U2 {

class CreateAnnotationWidgetController;
class ADVSequenceObjectContext;
class DNASequenceSelection;

class CreateFragmentDialog : public QDialog, public Ui_CreateFragmentDialog {
    Q_OBJECT
public:
    CreateFragmentDialog(ADVSequenceObjectContext* seqCtx, QWidget* p);
    CreateFragmentDialog(U2SequenceObject* seqObj, const U2Region& region, QWidget* p);
    virtual void accept();
    const DNAFragment& getFragment() { return dnaFragment; }
private:
    void setupAnnotationsWidget();

    CreateAnnotationWidgetController*   ac;
    U2SequenceObject*                   seqObj;
    QList<AnnotationTableObject *>      relatedAnnotations;
    QSet<QString>                       enzymesSelection;
    DNAFragment                         dnaFragment;
    RegionSelector*                     rs;
    ADVSequenceObjectContext*           seqCtx;
};


} //namespace

#endif //  _U2_CREATE_FRAGMENT_DIALOG_H_

==> ugene_40.1+dfsg.orig.tar.xz: ugene-40.1/src/plugins/enzymes/src/CreateFragmentDialog.h <==
/**
 * UGENE - Integrated Bioinformatics Tools.
 * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
 * http://ugene.net
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA 02110-1301, USA.
 */

#ifndef _U2_CREATE_FRAGMENT_DIALOG_H_
#define _U2_CREATE_FRAGMENT_DIALOG_H_

#include <ui_CreateFragmentDialog.h>

#include <QSet>

#include <U2Gui/RegionSelector.h>

#include "DNAFragment.h"

namespace U2 {

class CreateAnnotationWidgetController;
class ADVSequenceObjectContext;
class DNASequenceSelection;

class CreateFragmentDialog : public QDialog, public Ui_CreateFragmentDialog {
    Q_OBJECT
public:
    CreateFragmentDialog(ADVSequenceObjectContext *seqCtx, QWidget *p);
    CreateFragmentDialog(U2SequenceObject *seqObj, const U2Region &region, QWidget *p);
    virtual void accept();
    const DNAFragment &getFragment() {
        return dnaFragment;
    }

private:
    void setupAnnotationsWidget();

    CreateAnnotationWidgetController *ac;
    U2SequenceObject *seqObj;
    QList<AnnotationTableObject *> relatedAnnotations;
    QSet<QString> enzymesSelection;
    DNAFragment dnaFragment;
    RegionSelector *rs;
    ADVSequenceObjectContext *seqCtx;
};

}  // namespace U2

#endif  //  _U2_CREATE_FRAGMENT_DIALOG_H_
